# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreTagGetTagindexPerAreaParametersTagindex(BaseModel):
    """
    parameters
    """ # noqa: E501
    ctx: Optional[StrictInt] = Field(default=0, description="context id where to search for items")
    excl: Optional[StrictBool] = Field(default=False, description="exlusive mode for this tag area")
    var_from: Optional[StrictInt] = Field(default=0, description="context id where the link was displayed", alias="from")
    id: Optional[StrictInt] = Field(default=0, description="tag id")
    page: Optional[StrictInt] = Field(default=0, description="page number (0-based)")
    rec: Optional[StrictInt] = Field(default=0, description="search in the context recursive")
    ta: Optional[StrictInt] = Field(default=0, description="tag area id")
    tag: Optional[StrictStr] = Field(default='', description="tag name")
    tc: Optional[StrictInt] = Field(default=0, description="tag collection id")
    __properties: ClassVar[List[str]] = ["ctx", "excl", "from", "id", "page", "rec", "ta", "tag", "tc"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreTagGetTagindexPerAreaParametersTagindex from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if ctx (nullable) is None
        # and model_fields_set contains the field
        if self.ctx is None and "ctx" in self.model_fields_set:
            _dict['ctx'] = None

        # set to None if excl (nullable) is None
        # and model_fields_set contains the field
        if self.excl is None and "excl" in self.model_fields_set:
            _dict['excl'] = None

        # set to None if var_from (nullable) is None
        # and model_fields_set contains the field
        if self.var_from is None and "var_from" in self.model_fields_set:
            _dict['from'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if page (nullable) is None
        # and model_fields_set contains the field
        if self.page is None and "page" in self.model_fields_set:
            _dict['page'] = None

        # set to None if rec (nullable) is None
        # and model_fields_set contains the field
        if self.rec is None and "rec" in self.model_fields_set:
            _dict['rec'] = None

        # set to None if ta (nullable) is None
        # and model_fields_set contains the field
        if self.ta is None and "ta" in self.model_fields_set:
            _dict['ta'] = None

        # set to None if tag (nullable) is None
        # and model_fields_set contains the field
        if self.tag is None and "tag" in self.model_fields_set:
            _dict['tag'] = None

        # set to None if tc (nullable) is None
        # and model_fields_set contains the field
        if self.tc is None and "tc" in self.model_fields_set:
            _dict['tc'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreTagGetTagindexPerAreaParametersTagindex from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreTagGetTagindexPerAreaParametersTagindex" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "ctx": obj.get("ctx") if obj.get("ctx") is not None else 0,
            "excl": obj.get("excl") if obj.get("excl") is not None else False,
            "from": obj.get("from") if obj.get("from") is not None else 0,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "page": obj.get("page") if obj.get("page") is not None else 0,
            "rec": obj.get("rec") if obj.get("rec") is not None else 0,
            "ta": obj.get("ta") if obj.get("ta") is not None else 0,
            "tag": obj.get("tag") if obj.get("tag") is not None else '',
            "tc": obj.get("tc") if obj.get("tc") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModDataGetDatabasesByCoursesResponseDatabasesInner(BaseModel):
    """
    ModDataGetDatabasesByCoursesResponseDatabasesInner
    """ # noqa: E501
    addtemplate: Optional[StrictStr] = Field(description="addtemplate field")
    approval: StrictBool = Field(description="approval field")
    asearchtemplate: Optional[StrictStr] = Field(description="asearchtemplate field")
    assessed: Optional[StrictInt] = Field(default=0, description="assessed field")
    assesstimefinish: Optional[StrictInt] = Field(default=0, description="assesstimefinish field")
    assesstimestart: Optional[StrictInt] = Field(default=0, description="assesstimestart field")
    comments: StrictBool = Field(description="comments enabled")
    course: StrictInt = Field(description="Course id")
    coursemodule: StrictInt = Field(description="coursemodule")
    csstemplate: Optional[StrictStr] = Field(description="csstemplate field")
    defaultsort: StrictInt = Field(description="defaultsort field")
    defaultsortdir: StrictInt = Field(description="defaultsortdir field")
    editany: Optional[StrictBool] = Field(default=False, description="editany field (not used any more)")
    id: StrictInt = Field(description="Database id")
    intro: StrictStr = Field(description="The Database intro")
    introfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="introfiles")
    introformat: Optional[StrictInt] = Field(default=0, description="intro format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    jstemplate: Optional[StrictStr] = Field(description="jstemplate field")
    lang: Optional[StrictStr] = Field(description="Forced activity language")
    listtemplate: Optional[StrictStr] = Field(description="listtemplate field")
    listtemplatefooter: Optional[StrictStr] = Field(description="listtemplatefooter field")
    listtemplateheader: Optional[StrictStr] = Field(description="listtemplateheader field")
    manageapproved: StrictBool = Field(description="manageapproved field")
    maxentries: StrictInt = Field(description="maxentries field")
    name: StrictStr = Field(description="Database name")
    notification: Optional[StrictInt] = Field(default=0, description="notification field (not used any more)")
    requiredentries: StrictInt = Field(description="requiredentries field")
    requiredentriestoview: StrictInt = Field(description="requiredentriestoview field")
    rssarticles: StrictInt = Field(description="rssarticles field")
    rsstemplate: Optional[StrictStr] = Field(description="rsstemplate field")
    rsstitletemplate: Optional[StrictStr] = Field(description="rsstitletemplate field")
    scale: Optional[StrictInt] = Field(default=0, description="scale field")
    singletemplate: Optional[StrictStr] = Field(description="singletemplate field")
    timeavailablefrom: StrictInt = Field(description="timeavailablefrom field")
    timeavailableto: StrictInt = Field(description="timeavailableto field")
    timemodified: Optional[StrictInt] = Field(default=0, description="Time modified")
    timeviewfrom: StrictInt = Field(description="timeviewfrom field")
    timeviewto: StrictInt = Field(description="timeviewto field")
    __properties: ClassVar[List[str]] = ["addtemplate", "approval", "asearchtemplate", "assessed", "assesstimefinish", "assesstimestart", "comments", "course", "coursemodule", "csstemplate", "defaultsort", "defaultsortdir", "editany", "id", "intro", "introfiles", "introformat", "jstemplate", "lang", "listtemplate", "listtemplatefooter", "listtemplateheader", "manageapproved", "maxentries", "name", "notification", "requiredentries", "requiredentriestoview", "rssarticles", "rsstemplate", "rsstitletemplate", "scale", "singletemplate", "timeavailablefrom", "timeavailableto", "timemodified", "timeviewfrom", "timeviewto"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModDataGetDatabasesByCoursesResponseDatabasesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in introfiles (list)
        _items = []
        if self.introfiles:
            for _item_introfiles in self.introfiles:
                if _item_introfiles:
                    _items.append(_item_introfiles.to_dict())
            _dict['introfiles'] = _items
        # set to None if addtemplate (nullable) is None
        # and model_fields_set contains the field
        if self.addtemplate is None and "addtemplate" in self.model_fields_set:
            _dict['addtemplate'] = None

        # set to None if asearchtemplate (nullable) is None
        # and model_fields_set contains the field
        if self.asearchtemplate is None and "asearchtemplate" in self.model_fields_set:
            _dict['asearchtemplate'] = None

        # set to None if csstemplate (nullable) is None
        # and model_fields_set contains the field
        if self.csstemplate is None and "csstemplate" in self.model_fields_set:
            _dict['csstemplate'] = None

        # set to None if introformat (nullable) is None
        # and model_fields_set contains the field
        if self.introformat is None and "introformat" in self.model_fields_set:
            _dict['introformat'] = None

        # set to None if jstemplate (nullable) is None
        # and model_fields_set contains the field
        if self.jstemplate is None and "jstemplate" in self.model_fields_set:
            _dict['jstemplate'] = None

        # set to None if lang (nullable) is None
        # and model_fields_set contains the field
        if self.lang is None and "lang" in self.model_fields_set:
            _dict['lang'] = None

        # set to None if listtemplate (nullable) is None
        # and model_fields_set contains the field
        if self.listtemplate is None and "listtemplate" in self.model_fields_set:
            _dict['listtemplate'] = None

        # set to None if listtemplatefooter (nullable) is None
        # and model_fields_set contains the field
        if self.listtemplatefooter is None and "listtemplatefooter" in self.model_fields_set:
            _dict['listtemplatefooter'] = None

        # set to None if listtemplateheader (nullable) is None
        # and model_fields_set contains the field
        if self.listtemplateheader is None and "listtemplateheader" in self.model_fields_set:
            _dict['listtemplateheader'] = None

        # set to None if rsstemplate (nullable) is None
        # and model_fields_set contains the field
        if self.rsstemplate is None and "rsstemplate" in self.model_fields_set:
            _dict['rsstemplate'] = None

        # set to None if rsstitletemplate (nullable) is None
        # and model_fields_set contains the field
        if self.rsstitletemplate is None and "rsstitletemplate" in self.model_fields_set:
            _dict['rsstitletemplate'] = None

        # set to None if singletemplate (nullable) is None
        # and model_fields_set contains the field
        if self.singletemplate is None and "singletemplate" in self.model_fields_set:
            _dict['singletemplate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModDataGetDatabasesByCoursesResponseDatabasesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModDataGetDatabasesByCoursesResponseDatabasesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "addtemplate": obj.get("addtemplate"),
            "approval": obj.get("approval") if obj.get("approval") is not None else False,
            "asearchtemplate": obj.get("asearchtemplate"),
            "assessed": obj.get("assessed") if obj.get("assessed") is not None else 0,
            "assesstimefinish": obj.get("assesstimefinish") if obj.get("assesstimefinish") is not None else 0,
            "assesstimestart": obj.get("assesstimestart") if obj.get("assesstimestart") is not None else 0,
            "comments": obj.get("comments") if obj.get("comments") is not None else False,
            "course": obj.get("course") if obj.get("course") is not None else 0,
            "coursemodule": obj.get("coursemodule") if obj.get("coursemodule") is not None else 0,
            "csstemplate": obj.get("csstemplate"),
            "defaultsort": obj.get("defaultsort") if obj.get("defaultsort") is not None else 0,
            "defaultsortdir": obj.get("defaultsortdir") if obj.get("defaultsortdir") is not None else 0,
            "editany": obj.get("editany") if obj.get("editany") is not None else False,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "intro": obj.get("intro") if obj.get("intro") is not None else '',
            "introfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["introfiles"]] if obj.get("introfiles") is not None else None,
            "introformat": obj.get("introformat") if obj.get("introformat") is not None else 0,
            "jstemplate": obj.get("jstemplate"),
            "lang": obj.get("lang"),
            "listtemplate": obj.get("listtemplate"),
            "listtemplatefooter": obj.get("listtemplatefooter"),
            "listtemplateheader": obj.get("listtemplateheader"),
            "manageapproved": obj.get("manageapproved") if obj.get("manageapproved") is not None else False,
            "maxentries": obj.get("maxentries") if obj.get("maxentries") is not None else 0,
            "name": obj.get("name") if obj.get("name") is not None else '',
            "notification": obj.get("notification") if obj.get("notification") is not None else 0,
            "requiredentries": obj.get("requiredentries") if obj.get("requiredentries") is not None else 0,
            "requiredentriestoview": obj.get("requiredentriestoview") if obj.get("requiredentriestoview") is not None else 0,
            "rssarticles": obj.get("rssarticles") if obj.get("rssarticles") is not None else 0,
            "rsstemplate": obj.get("rsstemplate"),
            "rsstitletemplate": obj.get("rsstitletemplate"),
            "scale": obj.get("scale") if obj.get("scale") is not None else 0,
            "singletemplate": obj.get("singletemplate"),
            "timeavailablefrom": obj.get("timeavailablefrom") if obj.get("timeavailablefrom") is not None else 0,
            "timeavailableto": obj.get("timeavailableto") if obj.get("timeavailableto") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "timeviewfrom": obj.get("timeviewfrom") if obj.get("timeviewfrom") is not None else 0,
            "timeviewto": obj.get("timeviewto") if obj.get("timeviewto") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreTagGetTagAreasResponseAreasInner(BaseModel):
    """
    CoreTagGetTagAreasResponseAreasInner
    """ # noqa: E501
    callback: Optional[StrictStr] = Field(description="Component callback for processing tags.")
    callbackfile: Optional[StrictStr] = Field(description="Component callback file.")
    component: StrictStr = Field(description="Component the area is related to.")
    enabled: StrictBool = Field(description="Whether this area is enabled.")
    id: StrictInt = Field(description="Area id.")
    itemtype: StrictStr = Field(description="Type of item in the component.")
    locked: Optional[StrictBool] = Field(default=False, description="Whether the area is locked.")
    multiplecontexts: StrictBool = Field(description="Whether the tag area allows tag instances to be created in multiple contexts. ")
    showstandard: StrictInt = Field(description="Return whether to display only standard, only non-standard or both tags.")
    tagcollid: StrictInt = Field(description="The tag collection this are belongs to.")
    __properties: ClassVar[List[str]] = ["callback", "callbackfile", "component", "enabled", "id", "itemtype", "locked", "multiplecontexts", "showstandard", "tagcollid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreTagGetTagAreasResponseAreasInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if callback (nullable) is None
        # and model_fields_set contains the field
        if self.callback is None and "callback" in self.model_fields_set:
            _dict['callback'] = None

        # set to None if callbackfile (nullable) is None
        # and model_fields_set contains the field
        if self.callbackfile is None and "callbackfile" in self.model_fields_set:
            _dict['callbackfile'] = None

        # set to None if locked (nullable) is None
        # and model_fields_set contains the field
        if self.locked is None and "locked" in self.model_fields_set:
            _dict['locked'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreTagGetTagAreasResponseAreasInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreTagGetTagAreasResponseAreasInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "callback": obj.get("callback"),
            "callbackfile": obj.get("callbackfile"),
            "component": obj.get("component") if obj.get("component") is not None else '',
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else True,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "itemtype": obj.get("itemtype") if obj.get("itemtype") is not None else '',
            "locked": obj.get("locked") if obj.get("locked") is not None else False,
            "multiplecontexts": obj.get("multiplecontexts") if obj.get("multiplecontexts") is not None else False,
            "showstandard": obj.get("showstandard") if obj.get("showstandard") is not None else 0,
            "tagcollid": obj.get("tagcollid") if obj.get("tagcollid") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_advancedgrading_inner import CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_outcomes_inner import CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCourseGetCourseModuleByInstanceResponseCm(BaseModel):
    """
    CoreCourseGetCourseModuleByInstanceResponseCm
    """ # noqa: E501
    added: Optional[StrictInt] = Field(default=None, description="Time added")
    advancedgrading: Optional[List[CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner]] = Field(default=None, description="Advanced grading settings")
    availability: Optional[StrictStr] = Field(default=None, description="Availability settings")
    completion: Optional[StrictInt] = Field(description="If completion is enabled")
    completionexpected: Optional[StrictInt] = Field(default=None, description="Completion time expected")
    completiongradeitemnumber: Optional[StrictInt] = Field(default=None, description="Completion grade item")
    completionpassgrade: Optional[StrictInt] = Field(default=None, description="Completion pass grade setting")
    completionview: Optional[StrictInt] = Field(default=None, description="Completion view setting")
    course: Optional[StrictInt] = Field(description="The course id")
    downloadcontent: Optional[StrictInt] = Field(default=None, description="The download content value")
    grade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Grade (max value or scale id)")
    gradecat: Optional[StrictInt] = Field(default=None, description="Grade category")
    gradepass: Optional[StrictStr] = Field(default=None, description="Grade to pass (float)")
    groupingid: Optional[StrictInt] = Field(description="Grouping id")
    groupmode: Optional[StrictInt] = Field(description="Group mode")
    id: Optional[StrictInt] = Field(description="The course module id")
    idnumber: Optional[StrictStr] = Field(default=None, description="Module id number")
    indent: Optional[StrictInt] = Field(default=None, description="Indentation")
    instance: Optional[StrictInt] = Field(description="The activity instance id")
    modname: Optional[StrictStr] = Field(description="The module component name (forum, assign, etc..)")
    module: Optional[StrictInt] = Field(description="The module type id")
    name: Optional[StrictStr] = Field(description="The activity name")
    outcomes: Optional[List[CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner]] = Field(default=None, description="Outcomes information")
    scale: Optional[StrictStr] = Field(default=None, description="Scale items (if used)")
    score: Optional[StrictInt] = Field(default=None, description="Score")
    section: Optional[StrictInt] = Field(description="The module section id")
    sectionnum: Optional[StrictInt] = Field(description="The module section number")
    showdescription: Optional[StrictInt] = Field(default=None, description="If the description is showed")
    visible: Optional[StrictInt] = Field(default=None, description="If visible")
    visibleold: Optional[StrictInt] = Field(default=None, description="Visible old")
    visibleoncoursepage: Optional[StrictInt] = Field(default=None, description="If visible on course page")
    __properties: ClassVar[List[str]] = ["added", "advancedgrading", "availability", "completion", "completionexpected", "completiongradeitemnumber", "completionpassgrade", "completionview", "course", "downloadcontent", "grade", "gradecat", "gradepass", "groupingid", "groupmode", "id", "idnumber", "indent", "instance", "modname", "module", "name", "outcomes", "scale", "score", "section", "sectionnum", "showdescription", "visible", "visibleold", "visibleoncoursepage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCourseGetCourseModuleByInstanceResponseCm from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in advancedgrading (list)
        _items = []
        if self.advancedgrading:
            for _item_advancedgrading in self.advancedgrading:
                if _item_advancedgrading:
                    _items.append(_item_advancedgrading.to_dict())
            _dict['advancedgrading'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in outcomes (list)
        _items = []
        if self.outcomes:
            for _item_outcomes in self.outcomes:
                if _item_outcomes:
                    _items.append(_item_outcomes.to_dict())
            _dict['outcomes'] = _items
        # set to None if added (nullable) is None
        # and model_fields_set contains the field
        if self.added is None and "added" in self.model_fields_set:
            _dict['added'] = None

        # set to None if availability (nullable) is None
        # and model_fields_set contains the field
        if self.availability is None and "availability" in self.model_fields_set:
            _dict['availability'] = None

        # set to None if completion (nullable) is None
        # and model_fields_set contains the field
        if self.completion is None and "completion" in self.model_fields_set:
            _dict['completion'] = None

        # set to None if completionexpected (nullable) is None
        # and model_fields_set contains the field
        if self.completionexpected is None and "completionexpected" in self.model_fields_set:
            _dict['completionexpected'] = None

        # set to None if completiongradeitemnumber (nullable) is None
        # and model_fields_set contains the field
        if self.completiongradeitemnumber is None and "completiongradeitemnumber" in self.model_fields_set:
            _dict['completiongradeitemnumber'] = None

        # set to None if completionpassgrade (nullable) is None
        # and model_fields_set contains the field
        if self.completionpassgrade is None and "completionpassgrade" in self.model_fields_set:
            _dict['completionpassgrade'] = None

        # set to None if completionview (nullable) is None
        # and model_fields_set contains the field
        if self.completionview is None and "completionview" in self.model_fields_set:
            _dict['completionview'] = None

        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if downloadcontent (nullable) is None
        # and model_fields_set contains the field
        if self.downloadcontent is None and "downloadcontent" in self.model_fields_set:
            _dict['downloadcontent'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if gradecat (nullable) is None
        # and model_fields_set contains the field
        if self.gradecat is None and "gradecat" in self.model_fields_set:
            _dict['gradecat'] = None

        # set to None if gradepass (nullable) is None
        # and model_fields_set contains the field
        if self.gradepass is None and "gradepass" in self.model_fields_set:
            _dict['gradepass'] = None

        # set to None if groupingid (nullable) is None
        # and model_fields_set contains the field
        if self.groupingid is None and "groupingid" in self.model_fields_set:
            _dict['groupingid'] = None

        # set to None if groupmode (nullable) is None
        # and model_fields_set contains the field
        if self.groupmode is None and "groupmode" in self.model_fields_set:
            _dict['groupmode'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if indent (nullable) is None
        # and model_fields_set contains the field
        if self.indent is None and "indent" in self.model_fields_set:
            _dict['indent'] = None

        # set to None if instance (nullable) is None
        # and model_fields_set contains the field
        if self.instance is None and "instance" in self.model_fields_set:
            _dict['instance'] = None

        # set to None if modname (nullable) is None
        # and model_fields_set contains the field
        if self.modname is None and "modname" in self.model_fields_set:
            _dict['modname'] = None

        # set to None if module (nullable) is None
        # and model_fields_set contains the field
        if self.module is None and "module" in self.model_fields_set:
            _dict['module'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if scale (nullable) is None
        # and model_fields_set contains the field
        if self.scale is None and "scale" in self.model_fields_set:
            _dict['scale'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if section (nullable) is None
        # and model_fields_set contains the field
        if self.section is None and "section" in self.model_fields_set:
            _dict['section'] = None

        # set to None if sectionnum (nullable) is None
        # and model_fields_set contains the field
        if self.sectionnum is None and "sectionnum" in self.model_fields_set:
            _dict['sectionnum'] = None

        # set to None if showdescription (nullable) is None
        # and model_fields_set contains the field
        if self.showdescription is None and "showdescription" in self.model_fields_set:
            _dict['showdescription'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        # set to None if visibleold (nullable) is None
        # and model_fields_set contains the field
        if self.visibleold is None and "visibleold" in self.model_fields_set:
            _dict['visibleold'] = None

        # set to None if visibleoncoursepage (nullable) is None
        # and model_fields_set contains the field
        if self.visibleoncoursepage is None and "visibleoncoursepage" in self.model_fields_set:
            _dict['visibleoncoursepage'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCourseGetCourseModuleByInstanceResponseCm from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCourseGetCourseModuleByInstanceResponseCm" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "added": obj.get("added"),
            "advancedgrading": [CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner.from_dict(_item) for _item in obj["advancedgrading"]] if obj.get("advancedgrading") is not None else None,
            "availability": obj.get("availability"),
            "completion": obj.get("completion"),
            "completionexpected": obj.get("completionexpected"),
            "completiongradeitemnumber": obj.get("completiongradeitemnumber"),
            "completionpassgrade": obj.get("completionpassgrade"),
            "completionview": obj.get("completionview"),
            "course": obj.get("course"),
            "downloadcontent": obj.get("downloadcontent"),
            "grade": obj.get("grade"),
            "gradecat": obj.get("gradecat"),
            "gradepass": obj.get("gradepass"),
            "groupingid": obj.get("groupingid"),
            "groupmode": obj.get("groupmode"),
            "id": obj.get("id"),
            "idnumber": obj.get("idnumber"),
            "indent": obj.get("indent"),
            "instance": obj.get("instance"),
            "modname": obj.get("modname"),
            "module": obj.get("module"),
            "name": obj.get("name"),
            "outcomes": [CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner.from_dict(_item) for _item in obj["outcomes"]] if obj.get("outcomes") is not None else None,
            "scale": obj.get("scale"),
            "score": obj.get("score"),
            "section": obj.get("section"),
            "sectionnum": obj.get("sectionnum"),
            "showdescription": obj.get("showdescription"),
            "visible": obj.get("visible"),
            "visibleold": obj.get("visibleold"),
            "visibleoncoursepage": obj.get("visibleoncoursepage")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose_formattedlawfulbases_inner import ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ToolDataprivacyCreatePurposeFormResponsePurpose(BaseModel):
    """
    ToolDataprivacyCreatePurposeFormResponsePurpose
    """ # noqa: E501
    description: Optional[StrictStr] = Field(description="The purpose description.")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    formattedlawfulbases: List[ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner] = Field(description="formattedlawfulbases")
    formattedretentionperiod: StrictStr = Field(description="formattedretentionperiod")
    formattedsensitivedatareasons: Optional[List[ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner]] = Field(default=None, description="formattedsensitivedatareasons")
    id: StrictInt = Field(description="id")
    lawfulbases: StrictStr = Field(description="Comma-separated IDs matching records in tool_dataprivacy_lawfulbasis.")
    name: StrictStr = Field(description="The purpose name.")
    protected: StrictInt = Field(description="Data retention with higher precedent over user's request to be forgotten.")
    retentionperiod: StrictStr = Field(description="Retention period. ISO_8601 durations format (as in DateInterval format).")
    roleoverrides: StrictStr = Field(description="roleoverrides")
    sensitivedatareasons: Optional[StrictStr] = Field(description="Comma-separated IDs matching records in tool_dataprivacy_sensitive")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["description", "descriptionformat", "formattedlawfulbases", "formattedretentionperiod", "formattedsensitivedatareasons", "id", "lawfulbases", "name", "protected", "retentionperiod", "roleoverrides", "sensitivedatareasons", "timecreated", "timemodified", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolDataprivacyCreatePurposeFormResponsePurpose from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in formattedlawfulbases (list)
        _items = []
        if self.formattedlawfulbases:
            for _item_formattedlawfulbases in self.formattedlawfulbases:
                if _item_formattedlawfulbases:
                    _items.append(_item_formattedlawfulbases.to_dict())
            _dict['formattedlawfulbases'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in formattedsensitivedatareasons (list)
        _items = []
        if self.formattedsensitivedatareasons:
            for _item_formattedsensitivedatareasons in self.formattedsensitivedatareasons:
                if _item_formattedsensitivedatareasons:
                    _items.append(_item_formattedsensitivedatareasons.to_dict())
            _dict['formattedsensitivedatareasons'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if sensitivedatareasons (nullable) is None
        # and model_fields_set contains the field
        if self.sensitivedatareasons is None and "sensitivedatareasons" in self.model_fields_set:
            _dict['sensitivedatareasons'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolDataprivacyCreatePurposeFormResponsePurpose from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ToolDataprivacyCreatePurposeFormResponsePurpose" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "description": obj.get("description") if obj.get("description") is not None else '',
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "formattedlawfulbases": [ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner.from_dict(_item) for _item in obj["formattedlawfulbases"]] if obj.get("formattedlawfulbases") is not None else None,
            "formattedretentionperiod": obj.get("formattedretentionperiod") if obj.get("formattedretentionperiod") is not None else '',
            "formattedsensitivedatareasons": [ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner.from_dict(_item) for _item in obj["formattedsensitivedatareasons"]] if obj.get("formattedsensitivedatareasons") is not None else None,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "lawfulbases": obj.get("lawfulbases") if obj.get("lawfulbases") is not None else '',
            "name": obj.get("name") if obj.get("name") is not None else '',
            "protected": obj.get("protected") if obj.get("protected") is not None else 0,
            "retentionperiod": obj.get("retentionperiod") if obj.get("retentionperiod") is not None else '',
            "roleoverrides": obj.get("roleoverrides") if obj.get("roleoverrides") is not None else '',
            "sensitivedatareasons": obj.get("sensitivedatareasons") if obj.get("sensitivedatareasons") is not None else '',
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModWorkshopGetSubmissionResponseSubmission(BaseModel):
    """
    ModWorkshopGetSubmissionResponseSubmission
    """ # noqa: E501
    attachment: Optional[StrictInt] = Field(description="Used by File API file_postupdate_standard_filemanager.")
    attachmentfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="attachmentfiles")
    authorid: StrictInt = Field(description="The author of the submission.")
    content: Optional[StrictStr] = Field(description="Submission text.")
    contentfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="contentfiles")
    contentformat: Optional[StrictInt] = Field(default=0, description="content format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    contenttrust: StrictInt = Field(description="The trust mode of the data.")
    example: Optional[StrictBool] = Field(description="Is this submission an example from teacher.")
    feedbackauthor: Optional[StrictStr] = Field(default=None, description="Teacher comment/feedback for the author of the submission, for example describing the reasons                     for the grade overriding.")
    feedbackauthorformat: Optional[StrictInt] = Field(default=0, description="feedbackauthor format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    grade: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Aggregated grade for the submission. The grade is a decimal number from interval 0..100.                     If NULL then the grade for submission has not been aggregated yet.")
    gradeover: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Grade for the submission manually overridden by a teacher. Grade is always from interval 0..100.                     If NULL then the grade is not overriden.")
    gradeoverby: Optional[StrictInt] = Field(default=None, description="The id of the user who has overridden the grade for submission.")
    id: StrictInt = Field(description="The primary key of the record.")
    late: StrictInt = Field(description="Has this submission been submitted after the deadline or during the assessment phase?")
    published: Optional[StrictBool] = Field(description="Shall the submission be available to other when the workshop is closed.")
    timecreated: StrictInt = Field(description="Timestamp when the work was submitted for the first time.")
    timegraded: Optional[StrictInt] = Field(default=None, description="The timestamp when grade or gradeover was recently modified.")
    timemodified: StrictInt = Field(description="Timestamp when the submission has been updated.")
    title: StrictStr = Field(description="The submission title.")
    workshopid: StrictInt = Field(description="The id of the workshop instance.")
    __properties: ClassVar[List[str]] = ["attachment", "attachmentfiles", "authorid", "content", "contentfiles", "contentformat", "contenttrust", "example", "feedbackauthor", "feedbackauthorformat", "grade", "gradeover", "gradeoverby", "id", "late", "published", "timecreated", "timegraded", "timemodified", "title", "workshopid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModWorkshopGetSubmissionResponseSubmission from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachmentfiles (list)
        _items = []
        if self.attachmentfiles:
            for _item_attachmentfiles in self.attachmentfiles:
                if _item_attachmentfiles:
                    _items.append(_item_attachmentfiles.to_dict())
            _dict['attachmentfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in contentfiles (list)
        _items = []
        if self.contentfiles:
            for _item_contentfiles in self.contentfiles:
                if _item_contentfiles:
                    _items.append(_item_contentfiles.to_dict())
            _dict['contentfiles'] = _items
        # set to None if attachment (nullable) is None
        # and model_fields_set contains the field
        if self.attachment is None and "attachment" in self.model_fields_set:
            _dict['attachment'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if contentformat (nullable) is None
        # and model_fields_set contains the field
        if self.contentformat is None and "contentformat" in self.model_fields_set:
            _dict['contentformat'] = None

        # set to None if example (nullable) is None
        # and model_fields_set contains the field
        if self.example is None and "example" in self.model_fields_set:
            _dict['example'] = None

        # set to None if feedbackauthor (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackauthor is None and "feedbackauthor" in self.model_fields_set:
            _dict['feedbackauthor'] = None

        # set to None if feedbackauthorformat (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackauthorformat is None and "feedbackauthorformat" in self.model_fields_set:
            _dict['feedbackauthorformat'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if gradeover (nullable) is None
        # and model_fields_set contains the field
        if self.gradeover is None and "gradeover" in self.model_fields_set:
            _dict['gradeover'] = None

        # set to None if gradeoverby (nullable) is None
        # and model_fields_set contains the field
        if self.gradeoverby is None and "gradeoverby" in self.model_fields_set:
            _dict['gradeoverby'] = None

        # set to None if published (nullable) is None
        # and model_fields_set contains the field
        if self.published is None and "published" in self.model_fields_set:
            _dict['published'] = None

        # set to None if timegraded (nullable) is None
        # and model_fields_set contains the field
        if self.timegraded is None and "timegraded" in self.model_fields_set:
            _dict['timegraded'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModWorkshopGetSubmissionResponseSubmission from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModWorkshopGetSubmissionResponseSubmission" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "attachment": obj.get("attachment") if obj.get("attachment") is not None else 0,
            "attachmentfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["attachmentfiles"]] if obj.get("attachmentfiles") is not None else None,
            "authorid": obj.get("authorid") if obj.get("authorid") is not None else 0,
            "content": obj.get("content"),
            "contentfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["contentfiles"]] if obj.get("contentfiles") is not None else None,
            "contentformat": obj.get("contentformat") if obj.get("contentformat") is not None else 0,
            "contenttrust": obj.get("contenttrust") if obj.get("contenttrust") is not None else 0,
            "example": obj.get("example") if obj.get("example") is not None else False,
            "feedbackauthor": obj.get("feedbackauthor"),
            "feedbackauthorformat": obj.get("feedbackauthorformat") if obj.get("feedbackauthorformat") is not None else 0,
            "grade": obj.get("grade"),
            "gradeover": obj.get("gradeover"),
            "gradeoverby": obj.get("gradeoverby"),
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "late": obj.get("late") if obj.get("late") is not None else 0,
            "published": obj.get("published") if obj.get("published") is not None else False,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timegraded": obj.get("timegraded"),
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "title": obj.get("title") if obj.get("title") is not None else '',
            "workshopid": obj.get("workshopid") if obj.get("workshopid") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


